==> maps_admin-7.x-1.1.tar.gz: maps_admin/template.php <==
<?php

/**
 * @file
 * Theme functions for MaPS Admin.
 */

/**
 * Implements hook_page_alter().
 */
function maps_admin_process_page($page) {
  // Viewport for mobile devices.
  drupal_add_html_head(
    array(
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'viewport',
        'content' => 'width=device-width, initial-scale=1, maximum-scale=1',
      )
    ),
    'viewport');

  // Horizontal scroll using mouse wheel.
  if (module_exists('libraries') && $jmw_path = libraries_get_path('jquery-mousewheel')) {
    if (file_exists($jmw_file = $jmw_path . '/jquery.mousewheel.js')) {
      drupal_add_js($jmw_file);
      drupal_add_js(array('mapsAdmin' => array('horizontalScroll' => '#main_content')), 'setting');
    }
  }
}

/**
 * Override the default theme for primary and secondary local tasks.
 *
 * @ingroup themeable
 * @see theme_menu_local_tasks()
 * @see menu_local_tasks()
 */
function maps_admin_menu_local_tasks(&$variables) {
  $output = '';

  if (!empty($variables['primary'])) {
    $variables['primary']['#prefix'] = '<h2 class="element-invisible">' . t('Primary tabs') . '</h2>';
    $variables['primary']['#prefix'] .= '<ul class="tabs primary">';
    $variables['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['primary']);
  }
  if (!empty($variables['secondary'])) {
    $variables['secondary']['#prefix'] = '<h2 class="element-invisible">' . t('Secondary tabs') . '</h2>';
    $variables['secondary']['#prefix'] .= '<div class="secondary_wrapper" /><ul class="tabs secondary">';
    $variables['secondary']['#suffix'] = '</ul></div>';
    $output .= drupal_render($variables['secondary']);
  }

  return $output;
}

==> maps_admin-7.x-1.3.tar.gz: maps_admin/template.php <==
<?php

/**
 * @file
 * Theme functions for MaPS Admin.
 */

/**
 * Implements hook_page_alter().
 */
function maps_admin_process_page($page) {
  // Viewport for mobile devices.
  drupal_add_html_head(
    array(
      '#tag' => 'meta',
      '#attributes' => array(
        'name' => 'viewport',
        'content' => 'width=device-width, initial-scale=1, maximum-scale=1',
      )
    ),
    'viewport');

  // Horizontal scroll using mouse wheel.
  if (module_exists('libraries') && $jmw_path = libraries_get_path('jquery-mousewheel')) {
    if (file_exists($jmw_file = $jmw_path . '/jquery.mousewheel.js')) {
      drupal_add_js($jmw_file);
      drupal_add_js(array('mapsAdmin' => array('scrollHorz' => '#main_content')), 'setting');
    }
  }
}

/**
 * Override the default theme for primary and secondary local tasks.
 *
 * @ingroup themeable
 * @see theme_menu_local_tasks()
 * @see menu_local_tasks()
 */
function maps_admin_menu_local_tasks(&$variables) {
  $output = '';

  if (!empty($variables['primary'])) {
    $variables['primary']['#prefix'] = '<h2 class="element-invisible">' . t('Primary tabs') . '</h2>';
    $variables['primary']['#prefix'] .= '<ul class="tabs primary">';
    $variables['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['primary']);
  }
  if (!empty($variables['secondary'])) {
    $variables['secondary']['#prefix'] = '<h2 class="element-invisible">' . t('Secondary tabs') . '</h2>';
    $variables['secondary']['#prefix'] .= '<div class="secondary_wrapper" /><ul class="tabs secondary">';
    $variables['secondary']['#suffix'] = '</ul></div>';
    $output .= drupal_render($variables['secondary']);
  }

  return $output;
}

/**
 * Implements hook_form_FORM_ID_alter().
 */
function maps_admin_form_field_ui_field_edit_form_alter(&$form, &$form_state) {
  $form['field']['#collapsible'] = TRUE;
  $form['field']['#collapsed'] = TRUE;
}
